Maintainers
===========

- Joel Payne <lilspazjoekp@gmail.com> `@LilSpazJoekp <https://github.com/LilSpazJoekp>`_

rstfmt Author
=============

- Danny Zhu <dzhu@dzhu.us> `@dzhu <https://github.com/dzhu>`_
